ParlAI is set up into several main directories:

- **core**: contains the primary code for the framework
- **agents**: contains agents which can interact with the different tasks (e.g. machine learning models)
- **scripts**: contains examples of different loops (building dictionary, train/eval, displaying data)
- **tasks**: contains code for the different tasks/datasets available from within ParlAI
- **zoo**: contains code to directly download and use pretrained models from our model zoo
- **mturk**: contains code for setting up Mechanical Turk, as well as sample MTurk tasks
- **chat_service**: contains code for interfacing with chat services, such as Facebook Messenger

See the top level README for more information (one directory above).
